package jp.a2kichi.android.itemsearch;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.TextView;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;
import java.util.Arrays;


public class ItemSearch extends Activity implements OnClickListener, Runnable{
    /** Called when the activity is first created. */
	private final Handler handler = new Handler();
	private Button Button;
	private TargetInfo targetInfo = new TargetInfo();
	private CheckBox checkBoxRakuten;
	private CheckBox checkBoxKakakucom;
	private CheckBox checkBoxYahoo;
    private ProgressDialog dialog;
	private InfoController infoController;
	
	public void onCreate(Bundle icicle) {
        Log.v("EXAM", "onCreate");
        super.onCreate(icicle);
        setContentView(R.layout.main);
    	initButton();
		initCheckBox();
    }

	private void initButton() {
    	Button      = (Button)findViewById(R.id.button_id);
        Button.setOnClickListener(this);
	}

	private void initCheckBox() {
		checkBoxRakuten = (CheckBox)findViewById(R.id.check_rakuten);
		checkBoxRakuten.setChecked(true);
    	targetInfo.setRakutenChecked(true);
		checkBoxRakuten.setOnCheckedChangeListener(
		    new CompoundButton.OnCheckedChangeListener() {
			    @Override
			    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
			    	targetInfo.setRakutenChecked(isChecked);
			    }
			}
		);
		checkBoxKakakucom = (CheckBox)findViewById(R.id.check_kakakucom);
		checkBoxKakakucom.setChecked(true);
    	targetInfo.setKakakucomChecked(true);
		checkBoxKakakucom.setOnCheckedChangeListener(
		    new CompoundButton.OnCheckedChangeListener() {
			    @Override
			    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
			    	targetInfo.setKakakucomChecked(isChecked);
			    }
			}
		);
		checkBoxYahoo = (CheckBox)findViewById(R.id.check_yahoo);
		checkBoxYahoo.setChecked(true);
    	targetInfo.setYahooChecked(true);
		checkBoxYahoo.setOnCheckedChangeListener(
		    new CompoundButton.OnCheckedChangeListener() {
			    @Override
			    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
			    	targetInfo.setYahooChecked(isChecked);
			    }
			}
		);
	}
    
	@Override
	public void onClick(View v) {
        Log.v("EXAM", "onClick");
    	EditText et = (EditText)findViewById(R.id.edit_text_id);
    	String word = et.getText().toString();
		infoController = new InfoController(handler, this, targetInfo, word);
        dialog = new ProgressDialog(this);
        dialog.setIndeterminate(true);
        dialog.setMessage(getText(R.string.dialog_message_getting_data));
        dialog.show();
        infoController.start();
	}

	@SuppressWarnings("unchecked")
	public void run() {
		
		dialog.dismiss();
        List<RakutenInfo> rakutenInfoList = infoController.getRakutenItemList();
        List<KakakuComInfo> kakakucomInfoList = infoController.getKakakuComItemList();
        List<YahooInfo> yahooInfoList = infoController.getYahooItemList();
        
        int rakuten_size = 0;
        int kakakucom_size = 0;
        int yahoo_size = 0;
        int max_size = 0;
        
        if(rakutenInfoList != null) {
			rakuten_size = rakutenInfoList.size();
        }
		if(kakakucomInfoList != null) {
			kakakucom_size = kakakucomInfoList.size();
		}
		if(yahooInfoList != null) {
			yahoo_size = yahooInfoList.size();
		}

        max_size = rakuten_size + kakakucom_size + yahoo_size;

        String[][] datas = new String[max_size][ 4 ];
        
        if(rakutenInfoList != null) {
			for(int i = 0; i < rakuten_size; i++) {
				RakutenInfo rakutenInfo = rakutenInfoList.get(i);
				datas [i][0] = rakutenInfo.service_name;
				datas [i][1] = rakutenInfo.item_name;
				datas [i][2] = rakutenInfo.item_price;
				datas [i][3] = rakutenInfo.item_url;
			}
        }
        if(kakakucomInfoList != null) {
			for(int i = 0; i < kakakucom_size; i++) {
		        int index = i + rakuten_size;
				KakakuComInfo kakakucomInfo = kakakucomInfoList.get(i);
				datas [index][0] = kakakucomInfo.service_name;
				datas [index][1] = kakakucomInfo.item_name;
				datas [index][2] = kakakucomInfo.item_price;
				datas [index][3] = kakakucomInfo.item_url;
			}
        }
        if(yahooInfoList != null) {
			for(int i = 0; i < yahoo_size; i++) {
		        int index = i + rakuten_size + kakakucom_size;
				YahooInfo yahooInfo = yahooInfoList.get(i);
				datas [index][0] = yahooInfo.service_name;
				datas [index][1] = yahooInfo.item_name;
				datas [index][2] = yahooInfo.item_price;
				datas [index][3] = yahooInfo.item_url;
			}
        }

        // 価格順でソート実施
        IntComparator comparator = new IntComparator();
        comparator.setIndex( 2 );
        Arrays.sort( datas, comparator );

        ArrayList<String> data = new ArrayList();
        ArrayList<String> url = new ArrayList();

        for(int i = 0; i < max_size; i++) {
			data.add("【" + datas[i][0] + "】" + datas[i][1] + " 価格：" + datas[i][2] + "円");
			url.add(datas[i][3]);
		}
		sendIntent(data, url);
    }
	
    private void sendIntent(ArrayList<String> data, ArrayList<String> url) {
        try {
            Intent i = new Intent(this, ResultList.class);
    		i.putExtra("DATA", data);
    		i.putExtra("URL", url);
            startActivity(i);
        } catch (Exception e) {
            TextView t = (TextView)findViewById(R.id.edit_text_id);
            t.setText(e.toString());
        }
    }
}